/****************************************************************************************
*  YAROCK                                                                               *
*  Copyright (c) 2010-2013 Sebastien amardeilh <sebastien.amardeilh+yarock@gmail.com>   *
*                                                                                       *
*  This program is free software; you can redistribute it and/or modify it under        *
*  the terms of the GNU General Public License as published by the Free Software        *
*  Foundation; either version 2 of the License, or (at your option) any later           *
*  version.                                                                             *
*                                                                                       *
*  This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
*  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
*  PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
*                                                                                       *
*  You should have received a copy of the GNU General Public License along with         *
*  this program.  If not, see <http://www.gnu.org/licenses/>.                           *
*****************************************************************************************/

#include "Dialog/aboutdialog.h"
#include "constants.h"

#include <QtGui>
#include <QtCore>

/*
********************************************************************************
*                                                                              *
*    Class AboutDialog                                                         *
*                                                                              *
********************************************************************************
*/
AboutDialog::AboutDialog(QWidget *parent) : QDialog(parent)
{
    this->setWindowTitle(tr("About yarock"));
    this->resize(420, 500);

    QLabel *title = new QLabel(this);
    title->setText(APP_NAME);

    QFont title_font;
    title_font.setBold(true);
    title_font.setPointSize(title_font.pointSize() + 4);
    title->setFont(title_font);

    QLabel *version = new QLabel(this);
    version->setText(VERSION);

    QLabel *copyright = new QLabel(this);
    copyright->setText("(c) 2010-2013 yarock author");

    QLabel *icon = new QLabel(this);
    icon->setPixmap( QPixmap(":/icon/64x64/yarock.png") );
    icon->setSizePolicy(QSizePolicy::Minimum, QSizePolicy::Minimum);

    QFrame *line = new QFrame(this);
    line->setFrameShape(QFrame::HLine);
    line->setFrameShadow(QFrame::Sunken);
    line->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Minimum);


    QVBoxLayout * vl0 = new QVBoxLayout();
    vl0->setContentsMargins(10,10,10,10);
    vl0->addWidget(title);
    vl0->addWidget(version);
    vl0->addWidget(copyright);
    vl0->addWidget(line);

    QVBoxLayout * vl1 = new QVBoxLayout();
    vl1->addWidget(icon);

    QHBoxLayout * hl0 = new QHBoxLayout();
    hl0->addLayout(vl1);
    hl0->addLayout(vl0);

    QTextBrowser* content = new QTextBrowser();
    content->setOpenExternalLinks(true);
    content->setSizePolicy(QSizePolicy::Expanding, QSizePolicy::Expanding);
    content->setStyleSheet("QTextBrowser { background:transparent }");
    content->setFrameShape(QFrame::NoFrame);


    content->setHtml("<dl>"
                     "<dt><b>About</b></dt>"
                     "<dd>"
                     "Yarock is Qt4 Modern Music Player designed to provide an easy and pretty music collection browser based on cover art."
                     " It's a Free Software distributed under the <a href=\"http://www.gnu.org/licenses/gpl-3.0.en.html\">(GPLv3)</a> license."
                     " Project is hosted on <a href=\"https://launchpad.net/yarock\">launchpad</a> repository."
                     "</dd>"
                     "<br>"
                     "<dt><b>Author</b></dt>"
                     "<dd>"
                     "Yarock is developped by <b>Sebastien Amardeilh</b> <a href=\"mailto:sebastien.amardeilh+yarock@gmail.com\">(sebastien.amardeilh+yarock@gmail.com)</a>"
                     "</dd>"
                     "<br>"
                     "<dt><b>Bugs report</b></dt>"
                     "<dd>Please use <a href=\"https://bugs.launchpad.net/yarock\">https://bugs.launchpad.net/yarock</a> to report bugs."
                     "</dd>"
                     "<br>"
                     "<dt><b>Translations</b></dt>"
                     "<dd>Please use <a href=\"https://www.transifex.net/projects/p/yarock-translation/\">transifex</a> for translations."
                     "</dd>"
                     "<br>"
                     "<dt><b>Donation</b></dt>"
                     "<dd>If you can, please <a href=\"https://www.paypal.com/cgi-bin/webscr?cmd=_s-xclick&hosted_button_id=PBL2A87TRZPH4\">donate</a> to support the development</dd>"
                     "</dl>");

    /*      close layout   */
    QDialogButtonBox* ui_buttonBox = new QDialogButtonBox();
    ui_buttonBox->setGeometry(QRect(140, 110, 291, 32));
    ui_buttonBox->setOrientation(Qt::Horizontal);
    ui_buttonBox->setStandardButtons(QDialogButtonBox::Ok);
    QObject::connect(ui_buttonBox, SIGNAL(accepted()), this, SLOT(close()));

    /*      final layout   */
    QVBoxLayout* layout = new QVBoxLayout();
    layout->addLayout(hl0);
    layout->addWidget(content);
    layout->addWidget(ui_buttonBox);

    this->setLayout(layout);
}

