/****************************************************************************************
*  YAROCK                                                                               *
*  Copyright (c) 2010-2013 Sebastien amardeilh <sebastien.amardeilh+yarock@gmail.com>   *
*                                                                                       *
*  This program is free software; you can redistribute it and/or modify it under        *
*  the terms of the GNU General Public License as published by the Free Software        *
*  Foundation; either version 2 of the License, or (at your option) any later           *
*  version.                                                                             *
*                                                                                       *
*  This program is distributed in the hope that it will be useful, but WITHOUT ANY      *
*  WARRANTY; without even the implied warranty of MERCHANTABILITY or FITNESS FOR A      *
*  PARTICULAR PURPOSE. See the GNU General Public License for more details.             *
*                                                                                       *
*  You should have received a copy of the GNU General Public License along with         *
*  this program.  If not, see <http://www.gnu.org/licenses/>.                           *
*****************************************************************************************/

#ifndef _PLAYLIST_MODEL_H_
#define _PLAYLIST_MODEL_H_

#include <QtGui>
#include <QMutex>

#include "MediaItem/mediaitem.h"
#include "MediaItem/mediamimedata.h"


/*
********************************************************************************
*                                                                              *
*    Class PlaylistModel                                                       *
*                                                                              *
********************************************************************************
*/
class PlaylistProxyModel;
class TaskManager;

class PlaylistModel : public QAbstractListModel
{
Q_OBJECT
  public:
    PlaylistModel(QObject* parent = 0);

    //! inherited from QAbstractListModel
    int rowCount(const QModelIndex &parent = QModelIndex()) const;
    QVariant data(const QModelIndex &index, int role) const;
    bool removeRows(int position, int count, const QModelIndex &parent);

    //! drag and drop
    Qt::ItemFlags flags(const QModelIndex &index) const;
    QStringList mimeTypes() const;
    Qt::DropActions supportedDropActions() const;
    QMimeData* mimeData( const QModelIndexList &indexes ) const;
    bool dropMimeData(const QMimeData *data,
                      Qt::DropAction action, int row, int column,
                      const QModelIndex &parent);

    void move(const MediaMimeData *data, int row);

    //! custom methods
    bool rowExists( int row ) const { return (( row >= 0 ) && ( row < m_tracks.size() ) ); }
    int rowForTrack(const MEDIA::TrackPtr track);

    QList<MEDIA::TrackPtr>   tracks() {return m_tracks;}
    
    MEDIA::TrackPtr MediaItemAt( int row ) const;
    QString getListDuration();

    //! get Unplayed mediaItem
    QList<MEDIA::TrackPtr> unplayedMediaItem();

    //! playing MediaItem method
    void stopPlayingItem();    
    void updatePlayingItem(MEDIA::TrackPtr);
    void updateBrokenItem(MEDIA::TrackPtr);
    int getPlayingRow();
    
    //! Requested MediaItem method
    void setRequestedMediaItem(int row);
    MEDIA::TrackPtr getRequestedMediaItem() const;

    //! add/insert mediaitem
    void addMediaItem(const MEDIA::TrackPtr mediaitem);
    void addMediaItems(QList<MEDIA::TrackPtr>);
    void insertMediaItem(const MEDIA::TrackPtr mediaitem, int pos=-1);
    void removeDuplicate();

    //! Stop After media Action
    MEDIA::TrackPtr stopAfterTrack() const;
    void setStopAfterTrack(MEDIA::TrackPtr track);

    //! play next/prev
    int skipBackward(bool repeat = false);
    int skipForward(bool repeat = false);
    
    //! Proxy Model
    QSortFilterProxyModel* proxy() const;
    bool filterContainsRow(int source_row);
    
    //! TaskManager
    TaskManager* manager() const;    

  public slots:
    void clear();
    void signalUpdate();
    void slot_sort(QVariant query);

  signals:
    void needSelectionAfterMove(QList<MEDIA::TrackPtr>);
    void updated();

  private:
    PlaylistProxyModel      *m_proxy_model;
    TaskManager             *m_task_manager;
    
    MEDIA::TrackPtr          m_playing_track;
    MEDIA::TrackPtr          m_requested_track;
    MEDIA::TrackPtr          m_stop_after_track;
    QList<MEDIA::TrackPtr>   m_tracks;
    QMutex                   m_mutex;
};

class Playqueue
{
public:
  Playqueue();
  static PlaylistModel* INSTANCE;
  static PlaylistModel* instance() { return INSTANCE; }
  
};

#endif // _PLAYLIST_MODEL_H_
